-- SIO IV Shader : Customizing, Version 1.0

local getExposure
local getContrast
local getTemperature
local getSaturation
local getVibrance
local getBrightness

local checkList = {
    "Exposure",
    "Contrast",
    "Temperature",
    "Saturation",
    "Vibrance",
    "Brightness"
}
local function checkGlobalVar()
    local checkNow
    for i = 1, #checkList do
        checkNow = checkList[i]
        checkNow = "sio4Global" .. checkNow
        checkResult = TheoTown.getGlobalFunVar(checkNow, 300)
        if checkResult == 300 then
            TheoTown.setGlobalFunVar(checkNow, 100)
        end
    end
end

local function activeShader()
    for i = 1, #checkList do
        TheoTown.setGlobalFunVar("sio4Global" .. checkList[i], TheoTown.getGlobalFunVar("sio4Global" .. checkList[i]))
        local globalValue = TheoTown.getGlobalFunVar("sio4Global" .. checkList[i])
        globalValue = globalValue / 100
        --Debug.toast("test")
        Drawing.setUniform("sio4" .. checkList[i], globalValue)
    end
end

function script:enterStage(name)
    if name == "LoadWaitingStage" then
        activeShader()
        checkGlobalVar()
        --Debug.toast("Finished")
    end
end

local function UI()
    local dialog
    dialog = GUI.createDialog{
        icon = Icon.REGION,
        title = 'Perameters',
        height = 280
    }
    
    local layout = dialog.content:addLayout{
        vertical = true
    }
  
    local function addLine(label, height)
        local line = layout:addLayout{height = height}
        line:addLabel{text = label, w = 60}
        return line:addLayout{ x = 62 }
    end
    
    local line0 = addLine('Exposure:', 26)
    line0:addSlider{
        minValue = -2,
        maxValue = 2,
        setValue = function(v)
            getExposure = v
            TheoTown.setGlobalFunVar("sio4Global" .. checkList[1], getExposure*100)
            Drawing.setUniform("sio4" .. checkList[1], TheoTown.getGlobalFunVar("sio4Global" .. checkList[1]) / 100)
        end,
        getValue = function() return TheoTown.getGlobalFunVar("sio4Global" .. checkList[1]) / 100 end
    }
    
    local line1 = addLine('Contrast:', 26)
    line1:addSlider{
        minValue = -2,
        maxValue = 2,
        setValue = function(v)
            getContrast = v
            TheoTown.setGlobalFunVar("sio4Global" .. checkList[2], getContrast*100)
            Drawing.setUniform("sio4" .. checkList[2], TheoTown.getGlobalFunVar("sio4Global" .. checkList[2]) / 100)
        end,
        getValue = function() return TheoTown.getGlobalFunVar("sio4Global" .. checkList[2]) / 100 end
    }
    
    local line2 = addLine('Temperature:', 26)
    line2:addSlider{
        minValue = -2,
        maxValue = 2,
        setValue = function(v) 
            getTemperature = v
            TheoTown.setGlobalFunVar("sio4Global" .. checkList[3], getTemperature*100)
            Drawing.setUniform("sio4" .. checkList[3], TheoTown.getGlobalFunVar("sio4Global" .. checkList[3]) / 100)
        end,
        getValue = function() return TheoTown.getGlobalFunVar("sio4Global" .. checkList[3]) / 100 end
    }
    
    local line3 = addLine('Saturation:', 26)
    line3:addSlider{
        minValue = -2,
        maxValue = 2,
        setValue = function(v) 
            getSaturation = v
            TheoTown.setGlobalFunVar("sio4Global" .. checkList[4], getSaturation*100)
            Drawing.setUniform("sio4" .. checkList[4], TheoTown.getGlobalFunVar("sio4Global" .. checkList[4]) / 100)
        end,
        getValue = function() return TheoTown.getGlobalFunVar("sio4Global" .. checkList[4]) / 100 end
    }
    
    local line4 = addLine('Vibrance:', 26)
    line4:addSlider{
        minValue = -2,
        maxValue = 2,
        setValue = function(v) 
            getVibrance = v
            TheoTown.setGlobalFunVar("sio4Global" .. checkList[5], getVibrance*100)
            Drawing.setUniform("sio4" .. checkList[5], TheoTown.getGlobalFunVar("sio4Global" .. checkList[5]) / 100)
        end,
        getValue = function() return TheoTown.getGlobalFunVar("sio4Global" .. checkList[5]) / 100 end       
    }
    
    local line5 = addLine('Brightness:', 26)
    line5:addSlider{
        minValue = -2,
        maxValue = 2,
        setValue = function(v) 
            getBrightness = v
            TheoTown.setGlobalFunVar("sio4Global" .. checkList[6], getBrightness*100)
            Drawing.setUniform("sio4" .. checkList[6], TheoTown.getGlobalFunVar("sio4Global" .. checkList[6]) / 100)
        end,
        getValue = function() return TheoTown.getGlobalFunVar("sio4Global" .. checkList[6]) / 100 end
    }
    
    local line6 = addLine('', 26)
    line6:addButton{
        icon = Icon.TURN_LEFT,
        text = "Reset all",
        frameDefault = NinePatch.BUTTON,
        framePressed = NinePatch.BLUE_BUTTON_PRESSED,
        onClick = function()
            for i = 1, #checkList do
                TheoTown.setGlobalFunVar("sio4Global" .. checkList[i], 0)
                Drawing.setUniform("sio4" .. checkList[i], TheoTown.getGlobalFunVar("sio4Global" .. checkList[i]) / 100)
            end
            Debug.toast("Reset all successfully")
        end
    }
    
    local line7 = addLine('', 20)
    line7:addTextFrame{
        text = "For more information, please visit"
  }
    
  local line8 = addLine('Click >>>', 20)
  local textField = line8:addTextField{
      text = "https://forum.theotown.com/viewtopic.php?t=26220",
      w = -40
  }
  
  closeDialog = dialog.close
end

function script:init()
    if closeDialog then
        closeDialog()
        closeDialog = nil
        UI()
    end
end

function script:event(_, _, _, event)
    if event == Script.EVENT_TOOL_ENTER then
        GUI.get('cmdCloseTool'):click()
        UI()
    end
end